==> jc-1.4.0.tar.gz: gnu/java/nio/NIOServerSocket.h <==
// public final class gnu.java.nio.NIOServerSocket

// class file dependencies
// @dep_class 775fd4e387399628 gnu_java_nio_NIOServerSocket
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96cfb28c68d7280a java_net_ServerSocket

// header file dependencies
// @dep_header java_net_ServerSocket

#include "java/net/ServerSocket.h"

#ifndef _JC_gnu_java_nio_NIOServerSocket_H_
#define _JC_gnu_java_nio_NIOServerSocket_H_

// Forward structure declarations
struct _jc_gnu_java_net_PlainSocketImpl$object;
struct _jc_gnu_java_nio_ServerSocketChannelImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_Socket$object;
struct _jc_java_nio_channels_ServerSocketChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_NIOServerSocket$sub_refs	_jc_gnu_java_nio_NIOServerSocket$sub_refs;
typedef struct _jc_gnu_java_nio_NIOServerSocket$sub_nonrefs	_jc_gnu_java_nio_NIOServerSocket$sub_nonrefs;
typedef struct _jc_gnu_java_nio_NIOServerSocket$refs	_jc_gnu_java_nio_NIOServerSocket$refs;
typedef struct _jc_gnu_java_nio_NIOServerSocket$nonrefs	_jc_gnu_java_nio_NIOServerSocket$nonrefs;
typedef struct _jc_gnu_java_nio_NIOServerSocket$object	_jc_gnu_java_nio_NIOServerSocket$object;

typedef struct _jc_gnu_java_nio_NIOServerSocket$fields_struct	_jc_gnu_java_nio_NIOServerSocket$fields_struct;
typedef const struct _jc_gnu_java_nio_NIOServerSocket$vmethods	_jc_gnu_java_nio_NIOServerSocket$vmethods;
typedef const struct _jc_gnu_java_nio_NIOServerSocket$vtable	_jc_gnu_java_nio_NIOServerSocket$vtable;
typedef const struct _jc_gnu_java_nio_NIOServerSocket$vtype	_jc_gnu_java_nio_NIOServerSocket$vtype;

// Class fields structure
struct _jc_gnu_java_nio_NIOServerSocket$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24net__24ServerSocket;
};
extern _jc_gnu_java_nio_NIOServerSocket$fields_struct _jc_gnu_java_nio_NIOServerSocket$class_fields;

// Constructors
extern void _jc_gnu_java_nio_NIOServerSocket$method$_init$2061f4a4f3d9fd47(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *);

// Virtual methods
extern struct _jc_java_net_Socket$object *_jc_gnu_java_nio_NIOServerSocket$method$accept$9d67bc0ae5d62a4d(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *);
extern struct _jc_java_nio_channels_ServerSocketChannel$object *_jc_gnu_java_nio_NIOServerSocket$method$getChannel$146e8940b9fd4e8c(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *);
extern struct _jc_gnu_java_net_PlainSocketImpl$object *_jc_gnu_java_nio_NIOServerSocket$method$getPlainSocketImpl$9130f35e50042eea(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_NIOServerSocket$method_info$accept$9d67bc0ae5d62a4d;
extern _jc_method _jc_gnu_java_nio_NIOServerSocket$method_info$getChannel$146e8940b9fd4e8c;
extern _jc_method _jc_gnu_java_nio_NIOServerSocket$method_info$getPlainSocketImpl$9130f35e50042eea;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_nio_NIOServerSocket$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_nio_NIOServerSocket$vmethods {
	struct _jc_java_net_Socket$object	*(*accept$9d67bc0ae5d62a4d)(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *);
	struct _jc_java_nio_channels_ServerSocketChannel$object	*(*getChannel$146e8940b9fd4e8c)(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *);
	struct _jc_gnu_java_net_PlainSocketImpl$object	*(*getPlainSocketImpl$9130f35e50042eea)(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *);
};

// Vtable
struct _jc_gnu_java_nio_NIOServerSocket$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_ServerSocket$vmethods	java_net_ServerSocket;
	_jc_gnu_java_nio_NIOServerSocket$vmethods	gnu_java_nio_NIOServerSocket;
};

// Vtype
struct _jc_gnu_java_nio_NIOServerSocket$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_NIOServerSocket$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_NIOServerSocket$sub_refs {
	struct _jc_gnu_java_nio_ServerSocketChannelImpl$object	*channel;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_NIOServerSocket$refs {
    _jc_gnu_java_nio_NIOServerSocket$sub_refs	gnu_java_nio_NIOServerSocket;
    _jc_java_net_ServerSocket$sub_refs	java_net_ServerSocket;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_NIOServerSocket$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_NIOServerSocket$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_ServerSocket$sub_nonrefs	java_net_ServerSocket;
    _jc_gnu_java_nio_NIOServerSocket$sub_nonrefs	gnu_java_nio_NIOServerSocket;
};

// Object instance structure
struct _jc_gnu_java_nio_NIOServerSocket$object {
	_jc_gnu_java_nio_NIOServerSocket$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_NIOServerSocket$vtype	*vtype;
	_jc_gnu_java_nio_NIOServerSocket$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_NIOServerSocket$vtype _jc_gnu_java_nio_NIOServerSocket$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_NIOServerSocket, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_NIOServerSocket$class_object;

#endif	/* _JC_gnu_java_nio_NIOServerSocket_H_ */

==> jc-1.4.5.tar.gz: gnu/java/nio/NIOServerSocket.h <==
// public final class gnu.java.nio.NIOServerSocket

// class file dependencies
// @dep_class 775fd4e387399628 gnu_java_nio_NIOServerSocket
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96cfb28c68d7280a java_net_ServerSocket

// header file dependencies
// @dep_header java_net_ServerSocket

#include "java/net/ServerSocket.h"

#ifndef _JC_gnu_java_nio_NIOServerSocket_H_
#define _JC_gnu_java_nio_NIOServerSocket_H_

// Forward structure declarations
struct _jc_gnu_java_net_PlainSocketImpl$object;
struct _jc_gnu_java_nio_ServerSocketChannelImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_Socket$object;
struct _jc_java_nio_channels_ServerSocketChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_NIOServerSocket$sub_refs	_jc_gnu_java_nio_NIOServerSocket$sub_refs;
typedef struct _jc_gnu_java_nio_NIOServerSocket$sub_nonrefs	_jc_gnu_java_nio_NIOServerSocket$sub_nonrefs;
typedef struct _jc_gnu_java_nio_NIOServerSocket$refs	_jc_gnu_java_nio_NIOServerSocket$refs;
typedef struct _jc_gnu_java_nio_NIOServerSocket$nonrefs	_jc_gnu_java_nio_NIOServerSocket$nonrefs;
typedef struct _jc_gnu_java_nio_NIOServerSocket$object	_jc_gnu_java_nio_NIOServerSocket$object;

typedef struct _jc_gnu_java_nio_NIOServerSocket$fields_struct	_jc_gnu_java_nio_NIOServerSocket$fields_struct;
typedef const struct _jc_gnu_java_nio_NIOServerSocket$vmethods	_jc_gnu_java_nio_NIOServerSocket$vmethods;
typedef const struct _jc_gnu_java_nio_NIOServerSocket$vtable	_jc_gnu_java_nio_NIOServerSocket$vtable;
typedef const struct _jc_gnu_java_nio_NIOServerSocket$vtype	_jc_gnu_java_nio_NIOServerSocket$vtype;

// Class fields structure
struct _jc_gnu_java_nio_NIOServerSocket$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24net__24ServerSocket;
};
extern _jc_gnu_java_nio_NIOServerSocket$fields_struct _jc_gnu_java_nio_NIOServerSocket$class_fields;

// Constructors
extern void _jc_gnu_java_nio_NIOServerSocket$method$_init$2061f4a4f3d9fd47(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_net_Socket$object *_jc_gnu_java_nio_NIOServerSocket$method$accept$9d67bc0ae5d62a4d(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_ServerSocketChannel$object *_jc_gnu_java_nio_NIOServerSocket$method$getChannel$146e8940b9fd4e8c(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_net_PlainSocketImpl$object *_jc_gnu_java_nio_NIOServerSocket$method$getPlainSocketImpl$9130f35e50042eea(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_NIOServerSocket$method_info$accept$9d67bc0ae5d62a4d;
extern _jc_method _jc_gnu_java_nio_NIOServerSocket$method_info$getChannel$146e8940b9fd4e8c;
extern _jc_method _jc_gnu_java_nio_NIOServerSocket$method_info$getPlainSocketImpl$9130f35e50042eea;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_nio_NIOServerSocket$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_nio_NIOServerSocket$vmethods {
	struct _jc_java_net_Socket$object	*(*accept$9d67bc0ae5d62a4d)(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_ServerSocketChannel$object	*(*getChannel$146e8940b9fd4e8c)(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_java_net_PlainSocketImpl$object	*(*getPlainSocketImpl$9130f35e50042eea)(_jc_env *, struct _jc_gnu_java_nio_NIOServerSocket$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_NIOServerSocket$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_ServerSocket$vmethods	java_net_ServerSocket;
	_jc_gnu_java_nio_NIOServerSocket$vmethods	gnu_java_nio_NIOServerSocket;
};

// Vtype
struct _jc_gnu_java_nio_NIOServerSocket$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_NIOServerSocket$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_NIOServerSocket$sub_refs {
	struct _jc_gnu_java_nio_ServerSocketChannelImpl$object	*channel;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_NIOServerSocket$refs {
    _jc_gnu_java_nio_NIOServerSocket$sub_refs	gnu_java_nio_NIOServerSocket;
    _jc_java_net_ServerSocket$sub_refs	java_net_ServerSocket;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_NIOServerSocket$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_NIOServerSocket$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_ServerSocket$sub_nonrefs	java_net_ServerSocket;
    _jc_gnu_java_nio_NIOServerSocket$sub_nonrefs	gnu_java_nio_NIOServerSocket;
};

// Object instance structure
struct _jc_gnu_java_nio_NIOServerSocket$object {
	_jc_gnu_java_nio_NIOServerSocket$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_NIOServerSocket$vtype	*vtype;
	_jc_gnu_java_nio_NIOServerSocket$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_NIOServerSocket$vtype _jc_gnu_java_nio_NIOServerSocket$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_NIOServerSocket, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_NIOServerSocket$class_object;

#endif	/* _JC_gnu_java_nio_NIOServerSocket_H_ */
